#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from PyQt5.QtCore import Qt, QByteArray
from PyQt5.QtWidgets import QApplication
from typing import Optional, List
from re import sub, search
from astra_csp_cryptopro.process import Process
from astra_csp_cryptopro.utils import Utils


translate = QApplication.translate


class CprocspProcess(Process):
    __question_keys = {Qt.Key_Y: ['Yes[Y]', 'Да[Y]'],
                       Qt.Key_N: ['No[N]', 'Нет[N]'],
                       Qt.Key_C: ['Cancel[C]', 'Отмена[C]']}

    def __init__(self) -> None:
        super().__init__()

    def output_error_code(self) -> Optional[str]:
        output = Utils.to_utf8(self.standard_output_buffer)
        math = search(r'\[ErrorCode:\s+(?P<code>.+)]', output)
        if math:
            return math.group('code')
        else:
            return None

    def failed_output_error_code_occurred(self) -> bool:
        code = self.output_error_code()
        return code is not None and code != '0x00000000'

    def timestamp_error_occurred(self) -> bool:
        return self.output_error_code() == '0xc2100100'

    def output(self) -> str:
        text = Utils.to_utf8(self.standard_output_buffer)
        text = sub('\\s\\d+%', '', text.replace('\n', '<br>').replace('', ''))
        if self.timestamp_error_occurred():
            text += '<br>' + translate('text', 'Error: Timestamp not received')

        return text

    @classmethod
    def question_keys(cls, array: QByteArray) -> List[Qt.Key]:
        found_keys = []  # type: List[Qt.Key]
        text = Utils.to_utf8(array)
        lines = text.split('\n')
        for line in lines:
            for key, aliases in cls.__question_keys.items():
                for alias in aliases:
                    if line.find(alias) > 0:
                        found_keys.append(key)

        return found_keys
